@@ -15,6 +15,8 @@ pub struct Eraser {
     connector_type: ConnectorType,
     pub alias: Option<String>,
     pub description: Option<String>,
+    #[serde(alias = "data")]
+    pub data_type: String,
     #[serde(alias = "exclude")]
     pub exclude_paths: Vec<String>,
 }
@@ -26,6 +28,7 @@ impl Default for Eraser {
             connector_type: ConnectorType::default(),
             alias: Some(uuid.to_simple().to_string()),
             description: None,
+            data_type: DataResult::OK.to_string(),
             exclude_paths: Vec::default(),
         }
     }
@@ -62,9 +65,17 @@ impl Step for Eraser {
 
         match (receiver_option, connector.is_variable()) {
             (Some(receiver), true) => {
-                for data_result in receiver {
-                    let json_value = data_result.to_json_value();
-                    connector.set_parameters(json_value.clone());
+                for data_result_received in receiver {
+                    if !data_result_received.is_type(self.data_type.as_ref()) {
+                        trace!(
+                            data_type_accepted = self.data_type.to_string().as_str(),
+                            data_result = format!("{:?}", data_result_received).as_str(),
+                            "This step handle only this data type"
+                        );
+                        continue;
+                    }
+
+                    connector.set_parameters(data_result_received.to_json_value().clone());
                     let path = connector.path();
 
                     if !exclude_paths.contains(&path) {
@@ -74,22 +85,23 @@ impl Step for Eraser {
                     }
 
                     if let Some(ref sender) = sender_option {
-                        trace!("Send data to the queue");
-                        sender
-                            .send(data_result.clone())
-                            .map_err(|e| io::Error::new(io::ErrorKind::Interrupted, e))?;
+                        self.send(data_result_received, sender)?;
                     }
                 }
             }
             (Some(receiver), false) => {
-                connector.erase().await?;
-                
-                for data_result in receiver {
+                for data_result_received in receiver {
+                    let path = connector.path();
+
+                    // erase when the step receive the first message
+                    if !exclude_paths.contains(&path) {
+                        connector.erase().await?;
+
+                        exclude_paths.push(path);
+                    }
+
                     if let Some(ref sender) = sender_option {
-                        trace!("Send data to the queue");
-                        sender
-                            .send(data_result.clone())
-                            .map_err(|e| io::Error::new(io::ErrorKind::Interrupted, e))?;
+                        self.send(data_result_received, sender)?;
                     }
                 }
             }
